# -*- coding: utf-8 -*-

FROM httpd:2.4.57-alpine3.17

LABEL authors="Nicolas Béjean <nicolas@bejean.fr>"
LABEL company="Béjean Développement"
LABEL website="www.bejean.eu"
LABEL version="1.0"

# Addgroup and adduser
RUN addgroup -g 1000 app \
&& adduser -D -H -h /var/www -s /sbin/nologin -G app -u 1000 app

# Change port 80 to 8000
RUN sed -i 's/Listen 80/Listen 8000/g' /usr/local/apache2/conf/httpd.conf

# Change user and group www-data to app
RUN sed -i 's/User www-data/User app/g' /usr/local/apache2/conf/httpd.conf
RUN sed -i 's/Group www-data/Group app/g' /usr/local/apache2/conf/httpd.conf

# Update server name
RUN sed -i 's/^#ServerName.*/ServerName localhost:8000/' /usr/local/apache2/conf/httpd.conf

# Enable proxy and fcgi modules
RUN sed -i 's/^#\(LoadModule proxy_module modules\/mod_proxy.so\)/\1/' /usr/local/apache2/conf/httpd.conf
RUN sed -i 's/^#\(LoadModule proxy_fcgi_module modules\/mod_proxy_fcgi.so\)/\1/' /usr/local/apache2/conf/httpd.conf

# Add vhost configuration and copye vhost file
RUN sed -i 's/#Include\ conf\/extra\/httpd-vhosts.conf/Include\ conf\/extra\/httpd-vhosts.conf/' /usr/local/apache2/conf/httpd.conf
COPY conf/httpd-vhosts.conf /usr/local/apache2/conf/extra/httpd-vhosts.conf

# Create directories and upate permissions
RUN mkdir -p /var/www/html \
&& chown -R app:app /var/www/html /usr/local/apache2/logs

# Change owner and group
USER app:app

# Change workdir
WORKDIR /var/www/html

# Expose port 8000
EXPOSE 8000

# Start apache
CMD /usr/local/apache2/bin/httpd -D FOREGROUND
